@@ -5,6 +5,13 @@ SUPPORTED_FORMATS = ['json']
 
 
 class MonitoringAPI(OAuth2API):
+    """
+    Monitoring API object.
+
+    This class represents an API object where users can fetch any kind of
+    monitoring data type. In order to grant the request, api_key or access_token
+    field must be provided when creating an instance.
+    """
 
     host = 'cendana15.com:8080'
     base_path = 'api/v1/'
@@ -79,6 +86,10 @@ class MonitoringAPI(OAuth2API):
         path='tiltborehole/{station}/',
         accepts_parameters=['station'])
 
+    fetch_tiltmeter_tlr = bind_method(
+        path='tiltmeter/tlr/{station}/',
+        accepts_parameters=['station'])
+
     fetch_seismicity = bind_method(path='seismicity/')
 
     fetch_bulletin = bind_method(path='bulletin/')
